---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Related issue**
(if exist)

**To Reproduce**
Steps to reproduce the behavior.

**Error Message**


**Expected behavior**


**Environment (please complete the following information):**
 - Hardware: [e.g. RaPi Zero W]
 - OS: [e.g. raspbian buster Lite]
 - Python [e.g. 3.6, pypy3.6.9-7.3.0]
 - Libraries:
   * Gtk: [e.g. 3.22.30]
   * vlc: [e.g. 3.0.8]
   * wpa_supplicant:
   * udhcpd:
   * tvservice:
 
**Additional context**
Add any other context about the problem here.
